@@ -46,6 +46,17 @@ namespace Model
     AWS_EC2_API CreateVolumeResponse& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);
 
 
+    ///@{
+    /**
+     * <p>The ID of the Availability Zone for the volume.</p>
+     */
+    inline const Aws::String& GetAvailabilityZoneId() const { return m_availabilityZoneId; }
+    template<typename AvailabilityZoneIdT = Aws::String>
+    void SetAvailabilityZoneId(AvailabilityZoneIdT&& value) { m_availabilityZoneIdHasBeenSet = true; m_availabilityZoneId = std::forward<AvailabilityZoneIdT>(value); }
+    template<typename AvailabilityZoneIdT = Aws::String>
+    CreateVolumeResponse& WithAvailabilityZoneId(AvailabilityZoneIdT&& value) { SetAvailabilityZoneId(std::forward<AvailabilityZoneIdT>(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>The Amazon Resource Name (ARN) of the Outpost.</p>
@@ -259,6 +270,9 @@ namespace Model
     ///@}
   private:
 
+    Aws::String m_availabilityZoneId;
+    bool m_availabilityZoneIdHasBeenSet = false;
+
     Aws::String m_outpostArn;
     bool m_outpostArnHasBeenSet = false;
 
