@@ -974,7 +974,64 @@ namespace Model
     c8gn_metal_24xl,
     c8gn_metal_48xl,
     f2_6xlarge,
-    p6e_gb200_36xlarge
+    p6e_gb200_36xlarge,
+    g6f_large,
+    g6f_xlarge,
+    g6f_2xlarge,
+    g6f_4xlarge,
+    gr6f_4xlarge,
+    p5_4xlarge,
+    r8i_large,
+    r8i_xlarge,
+    r8i_2xlarge,
+    r8i_4xlarge,
+    r8i_8xlarge,
+    r8i_12xlarge,
+    r8i_16xlarge,
+    r8i_24xlarge,
+    r8i_32xlarge,
+    r8i_48xlarge,
+    r8i_96xlarge,
+    r8i_metal_48xl,
+    r8i_metal_96xl,
+    r8i_flex_large,
+    r8i_flex_xlarge,
+    r8i_flex_2xlarge,
+    r8i_flex_4xlarge,
+    r8i_flex_8xlarge,
+    r8i_flex_12xlarge,
+    r8i_flex_16xlarge,
+    m8i_large,
+    m8i_xlarge,
+    m8i_2xlarge,
+    m8i_4xlarge,
+    m8i_8xlarge,
+    m8i_12xlarge,
+    m8i_16xlarge,
+    m8i_24xlarge,
+    m8i_32xlarge,
+    m8i_48xlarge,
+    m8i_96xlarge,
+    m8i_metal_48xl,
+    m8i_metal_96xl,
+    m8i_flex_large,
+    m8i_flex_xlarge,
+    m8i_flex_2xlarge,
+    m8i_flex_4xlarge,
+    m8i_flex_8xlarge,
+    m8i_flex_12xlarge,
+    m8i_flex_16xlarge,
+    i8ge_large,
+    i8ge_xlarge,
+    i8ge_2xlarge,
+    i8ge_3xlarge,
+    i8ge_6xlarge,
+    i8ge_12xlarge,
+    i8ge_18xlarge,
+    i8ge_24xlarge,
+    i8ge_48xlarge,
+    i8ge_metal_24xl,
+    i8ge_metal_48xl
   };
 
 namespace InstanceTypeMapper
