@@ -144,6 +144,18 @@ namespace Model
     inline ReservedInstancesOffering& WithScope(Scope value) { SetScope(value); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The ID of the Availability Zone.</p>
+     */
+    inline const Aws::String& GetAvailabilityZoneId() const { return m_availabilityZoneId; }
+    inline bool AvailabilityZoneIdHasBeenSet() const { return m_availabilityZoneIdHasBeenSet; }
+    template<typename AvailabilityZoneIdT = Aws::String>
+    void SetAvailabilityZoneId(AvailabilityZoneIdT&& value) { m_availabilityZoneIdHasBeenSet = true; m_availabilityZoneId = std::forward<AvailabilityZoneIdT>(value); }
+    template<typename AvailabilityZoneIdT = Aws::String>
+    ReservedInstancesOffering& WithAvailabilityZoneId(AvailabilityZoneIdT&& value) { SetAvailabilityZoneId(std::forward<AvailabilityZoneIdT>(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>The ID of the Reserved Instance offering. This is the offering ID used in
@@ -245,6 +257,9 @@ namespace Model
     Scope m_scope{Scope::NOT_SET};
     bool m_scopeHasBeenSet = false;
 
+    Aws::String m_availabilityZoneId;
+    bool m_availabilityZoneIdHasBeenSet = false;
+
     Aws::String m_reservedInstancesOfferingId;
     bool m_reservedInstancesOfferingIdHasBeenSet = false;
 
